@@ -37,163 +37,159 @@
 
 #include "cache.h"
 
-const gint MAGICHEAD=0xBC2002FC;
+const gint MAGICHEAD = 0xBC2002FC;
 
 /**
  * Global variables
  */
- 
+
 static GObjectClass *parent_class = NULL;
 
 /**
  * Internal functions forward declarations 
  */
- 
-static void file_cache_finalize(GObject *object);
 
-void file_cache_fill(FileCache *cache);
+static void file_cache_finalize(GObject * object);
+
+void file_cache_fill(FileCache * cache);
 
 void cache_entry_destroy(gpointer data);
 gint cache_entry_cmp(gconstpointer a, gconstpointer b, gpointer user_data);
-static gchar *strip_url(const gchar *url);
-
+static gchar *strip_url(const gchar * url);
+gboolean remove_file(gpointer key, gpointer value, gpointer user_data);
+gboolean remove_by_id(gpointer key, gpointer value, gpointer user_data);
+void remove_unwanted_entries(FileCache * cache, gint size);
+static gboolean write_str_safe(gint fd, const gchar * buffer);
+static gboolean write_safe(gint fd, const void *buffer, const gint buffer_size);
+static gboolean read_str_safe(gint fd, gchar ** result, guint max_size);
+static gboolean read_safe(gint fd, void *buffer, gint buffer_size);
+void file_cache_init(FileCache * self);
 /**
  * Object related stuff
  */
 
 //Class constructor
-static void
-file_cache_class_init(FileCacheClass *c)
+static void file_cache_class_init(FileCacheClass * c)
 {
     GObjectClass *object_class;
 
-    object_class = G_OBJECT_CLASS (c);
+    object_class = G_OBJECT_CLASS(c);
 
     parent_class = g_type_class_ref(G_TYPE_OBJECT);
     object_class->finalize = file_cache_finalize;
 }
 
 //Destructor
-static void
-file_cache_finalize(GObject *object)
+static void file_cache_finalize(GObject * object)
 {
     FileCache *cache = FILE_CACHE(object);
-    
+
     //maybe need to ensure that no threads are using the cache anymore
     g_free(cache->cache_dir);
     g_queue_free(cache->queue);
     g_hash_table_destroy(cache->hash);
-    
-    g_mutex_free(cache->lock);
-    
-    parent_class->finalize (object);
+
+
+    parent_class->finalize(object);
 }
 
 //Object constructor
-void
-file_cache_init(FileCache *self)
+void file_cache_init(FileCache * self)
 {
-    self->max_size = 64 * 1024 * 1024; //64M by default
+    self->max_size = 64 * 1024 * 1024;  //64M by default
     self->cache_dir = g_strdup_printf("%s" G_DIR_SEPARATOR_S ".cache",
-                        g_get_home_dir());
-    self->hash = g_hash_table_new_full (g_str_hash, g_str_equal, 
-        NULL, cache_entry_destroy);
+                                      g_get_home_dir());
+    self->hash = g_hash_table_new_full(g_str_hash, g_str_equal,
+                                       NULL, cache_entry_destroy);
     self->queue = g_queue_new();
-    self->lock = g_mutex_new();
 }
 
 //Object type
-GType
-file_cache_get_type (void)
+GType file_cache_get_type(void)
 {
     static GType type = 0;
 
-    if (type == 0) 
-    {
-        static const GTypeInfo type_info = 
-        {
-            sizeof (FileCacheClass),
-            NULL,                                     /* base_init */
-            NULL,                                     /* base_finalize */
-            (GClassInitFunc) file_cache_class_init,   /* class_init */
-            NULL,                                     /* class_finalize */
-            NULL,                                     /* class_data */
-            sizeof (FileCache),
-            0,                                        /* n_preallocs */
-            (GInstanceInitFunc) file_cache_init       /* instance_init */
+    if (type == 0) {
+        static const GTypeInfo type_info = {
+            sizeof(FileCacheClass),
+            NULL,               /* base_init */
+            NULL,               /* base_finalize */
+            (GClassInitFunc) file_cache_class_init, /* class_init */
+            NULL,               /* class_finalize */
+            NULL,               /* class_data */
+            sizeof(FileCache),
+            0,                  /* n_preallocs */
+            (GInstanceInitFunc) file_cache_init /* instance_init */
         };
 
         type = g_type_register_static(G_TYPE_OBJECT, "FileCacheType",
-                    &type_info,	0);
+                                      &type_info, 0);
     }
 
     return type;
 }
 
-FileCache *
-file_cache_new(const gchar *cache_dir, size_t max_size)
+FileCache *file_cache_new(const gchar * cache_dir, size_t max_size)
 {
     FileCache *cache = g_object_new(FILE_CACHE_TYPE, 0);
 
     if (max_size >= 0)
         cache->max_size = max_size;
-    if (cache_dir)
-    {
+    if (cache_dir) {
         g_free(cache->cache_dir);
         cache->cache_dir = g_strdup(cache_dir);
     }
-    
+
     g_mkdir_with_parents(cache->cache_dir, 0755);
-    
+
     file_cache_fill(cache);
-    
+
     return cache;
 }
 
-void 
-file_cache_destroy(FileCache *cache)
+void file_cache_destroy(FileCache * cache)
 {
     g_assert(IS_FILE_CACHE(cache));
-    
+
     g_object_unref(G_OBJECT(cache));
 }
 
-inline gboolean
-read_safe(gint fd, void *buffer, gint buffer_size)
+static gboolean read_safe(gint fd, void *buffer, gint buffer_size)
 {
     return read(fd, buffer, buffer_size) == buffer_size;
 }
 
-gboolean
-read_str_safe(gint fd, gchar **result, gint max_size)
+static gboolean read_str_safe(gint fd, gchar ** result, guint max_size)
 {
-    gint len = 0;
-    gboolean ret = FALSE;
-    
-    if (read_safe(fd, &len, sizeof(len)) && (len < max_size))
-    {
-        if (len)
-        {
-            *result = g_new(gchar, len+1);
-            if (!(ret = read_safe(fd, *result, len)))
-            {
-                g_free(*result);
-                *result = NULL;
+    guint len = 0;
+
+    if ( result ) *result = NULL;
+    else return FALSE;
+
+    if (read_safe(fd, &len, sizeof(len)) && len < max_size) {
+        if (0 == len) {
+            return TRUE;
+        }
+        else {
+            gchar* str = g_new(gchar, len + 1);
+            if (str) {
+                if (read_safe(fd, str, len)) {
+                    str[len] = 0;
+                    *result  = str;
+                    return TRUE;
+                }
+                g_free(str);
             }
-            *(*result+len) = 0;
         }
-        else
-            ret = TRUE;
     }
-    
-    return ret;
+
+    return FALSE;
 }
 
 /*
  * Fill the cache object from the specified cache directory
  */
-void 
-file_cache_fill(FileCache *cache)
+void file_cache_fill(FileCache * cache)
 {
     DIR *dir;
     struct dirent *dentry;
@@ -203,31 +199,26 @@ file_cache_fill(FileCache *cache)
     gint fsize;
     gint magic;
     gchar *url;
-    
+
     dir = opendir(cache->cache_dir);
-    while (dir && (dentry = readdir(dir)))
-    {
+    while (dir && (dentry = readdir(dir))) {
         //we intrested only in files
-        if (dentry->d_type == 8/*DT_REG*/)
-        {
+        if (dentry->d_type == 8 /*DT_REG */ ) {
             url = NULL;
             entry = NULL;
-            
-            fn = g_strconcat(cache->cache_dir, G_DIR_SEPARATOR_S, 
-                        dentry->d_name, 0);
+
+            fn = g_strconcat(cache->cache_dir, G_DIR_SEPARATOR_S,
+                             dentry->d_name, 0);
             fd = open(fn, O_RDONLY);
             fsize = lseek(fd, 0, SEEK_END);
             lseek(fd, 0, SEEK_SET);
-            if (read_safe(fd, &magic, sizeof(magic)) && (magic == MAGICHEAD) &&
-                read_str_safe(fd, &url, fsize))
-            {
-                if (url)
-                {
+            if (read_safe(fd, &magic, sizeof(magic)) && (magic == MAGICHEAD)
+                && read_str_safe(fd, &url, fsize)) {
+                if (url) {
                     entry = g_new0(CacheEntry, 1);
                     if (read_str_safe(fd, &entry->id, fsize) &&
-                        read_safe(fd, &entry->refcount, 
-                                sizeof(gint) + sizeof(GTimeVal)))
-                    {
+                        read_safe(fd, &entry->refcount,
+                                  sizeof(gint) + sizeof(GTimeVal))) {
                         entry->url = url;
                         entry->filename = fn;
                         entry->size = fsize;
@@ -241,8 +232,7 @@ file_cache_fill(FileCache *cache)
                     g_free(url);
             }
             close(fd);
-            if (entry)
-            {
+            if (entry) {
                 //maybe search in the cache first to remove duplicate files
                 g_hash_table_insert(cache->hash, url, entry);
                 g_queue_push_tail(cache->queue, entry);
@@ -252,47 +242,47 @@ file_cache_fill(FileCache *cache)
                 unlink(fn);
                 g_free(fn);
             }
-            
+
         }
     }
 
-    if (dir)    
+    if (dir)
         closedir(dir);
     g_queue_sort(cache->queue, cache_entry_cmp, NULL);
 }
 
-inline gboolean 
+static gboolean
 write_safe(gint fd, const void *buffer, const gint buffer_size)
 {
     return buffer_size == write(fd, buffer, buffer_size);
 }
 
-inline gboolean 
-write_str_safe(gint fd, const gchar *buffer)
+static gboolean write_str_safe(gint fd, const gchar * buffer)
 {
     gint len = buffer ? strlen(buffer) : 0;
-    return write_safe(fd, &len, sizeof(len)) && 
-            len ? write_safe(fd, buffer, len) : TRUE;
+    return write_safe(fd, &len, sizeof(len)) &&
+        len ? write_safe(fd, buffer, len) : TRUE;
 }
 
-void
-remove_unwanted_entries(FileCache *cache, gint size)
+void remove_unwanted_entries(FileCache * cache, gint size)
 {
     CacheEntry *entry = NULL;
-    while (size > 0 && (entry = CACHE_ENTRY(g_queue_pop_head(cache->queue))))
-    {
-        size -= entry->size;
-        cache->current_size -= entry->size;
-        unlink(entry->filename);
-      //TODO: Check why the entry->url could be NULL in some reason
-      if (cache->hash && entry->url)
-        g_hash_table_remove(cache->hash, entry->url);
+    while (size > 0 && (entry = CACHE_ENTRY(g_queue_pop_head(cache->queue)))) {
+        if (entry->refcount>1) {
+            size -= entry->size;
+            cache->current_size -= entry->size;
+            unlink(entry->filename);
+            //TODO: Check why the entry->url could be NULL in some reason
+            if (cache->hash && entry->url) {
+                g_hash_table_remove(cache->hash, entry->url);
+            }
+        }
     }
 }
 
 gboolean
-file_cache_add(FileCache *cache, const gchar *lurl, const gchar *id,
-    const gpointer buffer, const size_t buffer_size)
+file_cache_add(FileCache * cache, const gchar * lurl, const gchar * id,
+               const gpointer buffer, const size_t buffer_size)
 {
     CacheEntry *entry = NULL;
     struct statfs info;
@@ -300,15 +290,12 @@ file_cache_add(FileCache *cache, const gchar *lurl, const gchar *id,
     gint fd;
     size_t size;
     gchar *url = strip_url(lurl);
-    
+
     g_assert(IS_FILE_CACHE(cache));
 
-    if (url && cache->max_size && buffer && buffer_size)
-    {
-        g_mutex_lock(cache->lock);
-        
-        if ((entry = g_hash_table_lookup(cache->hash, url)))
-        {
+    if (url && cache->max_size && buffer && buffer_size) {
+
+        if ((entry = g_hash_table_lookup(cache->hash, url))) {
             unlink(entry->filename);
             cache->current_size -= entry->size;
             g_queue_unlink(cache->queue, entry->link);
@@ -318,38 +305,32 @@ file_cache_add(FileCache *cache, const gchar *lurl, const gchar *id,
         if (statfs(cache->cache_dir, &info) == 0) {
             //calculate the total size
             size = strlen(url) + sizeof(gint) +
-                   (id ? strlen(id) : 0) + sizeof(gint) +
-                   sizeof(gint) + 
-                   sizeof(GTimeVal) + 
-                   buffer_size;
-            
+                (id ? strlen(id) : 0) + sizeof(gint) +
+                sizeof(gint) + sizeof(GTimeVal) + buffer_size;
+
             //try to free up the cache a little bit, if it is full
             if (cache->current_size + size > cache->max_size &&
-                    size < cache->max_size)
+                size < cache->max_size)
                 remove_unwanted_entries(cache, size);
 
             //check if there is enough space
             if (cache->current_size + size <= cache->max_size &&
-                info.f_bavail * info.f_bsize > size)
-            {
+                info.f_bavail * info.f_bsize > size) {
                 tmp = g_strconcat(cache->cache_dir,
-                        G_DIR_SEPARATOR_S,
-                        "chXXXXXX", 0);
+                                  G_DIR_SEPARATOR_S, "chXXXXXX", 0);
                 fd = mkstemp(tmp);
-                
-                if (fd) 
-                {
+
+                if (fd) {
                     entry = g_new0(CacheEntry, 1);
-                    g_get_current_time (&entry->time);
-                    
+                    g_get_current_time(&entry->time);
+
                     //write the header + content
                     if (write_safe(fd, &MAGICHEAD, sizeof(MAGICHEAD)) &&
                         write_str_safe(fd, url) &&
-                        write_str_safe(fd, id) && 
-                        write_safe(fd, &entry->refcount, 
-                                 sizeof(gint)+sizeof(GTimeVal)) &&
-                        write_safe(fd, buffer, buffer_size))
-                    {
+                        write_str_safe(fd, id) &&
+                        write_safe(fd, &entry->refcount,
+                                   sizeof(gint) + sizeof(GTimeVal)) &&
+                        write_safe(fd, buffer, buffer_size)) {
                         entry->id = g_strdup(id);
                         entry->filename = tmp;
                         entry->size = lseek(fd, 0, SEEK_CUR);
@@ -361,8 +342,7 @@ file_cache_add(FileCache *cache, const gchar *lurl, const gchar *id,
                         g_queue_push_tail(cache->queue, entry);
                         entry->link = g_queue_peek_tail_link(cache->queue);
 
-                        g_mutex_unlock(cache->lock);
-                        
+
                         g_free(url);
                         return TRUE;
                     } else {
@@ -370,51 +350,46 @@ file_cache_add(FileCache *cache, const gchar *lurl, const gchar *id,
                         //faster then us :)
                         close(fd);
                         unlink(tmp);
-                        
+
                         g_free(tmp);
                         g_free(entry);
                     }
                 }
             }
-        } 
+        }
 
-        g_mutex_unlock(cache->lock);
     }
 
     g_free(url);
-    
+
     return FALSE;
 }
 
-gboolean
-file_cache_remove(FileCache *cache, const gchar *lurl)
+gboolean file_cache_remove(FileCache * cache, const gchar * lurl)
 {
     CacheEntry *entry = NULL;
     gchar *url = strip_url(lurl);
-    
+
     g_assert(IS_FILE_CACHE(cache));
 
-    g_mutex_lock(cache->lock);
 
-    if (url && cache->max_size && (entry = g_hash_table_lookup(cache->hash, url)))
-    {
+    if (url && cache->max_size
+        && (entry = g_hash_table_lookup(cache->hash, url))) {
         unlink(entry->filename);
-        
+
         cache->current_size -= entry->size;
         g_queue_unlink(cache->queue, entry->link);
         g_hash_table_remove(cache->hash, url);
 
-        g_mutex_unlock(cache->lock);
-        
+
         g_free(url);
-        
+
         return TRUE;
     }
-    
-    g_mutex_unlock(cache->lock);
-    
+
+
     g_free(url);
-    
+
     return FALSE;
 }
 
@@ -424,137 +399,119 @@ struct _RemoveByIdData {
     gchar *id;
 };
 
-gboolean
-remove_by_id(gpointer key, gpointer value, gpointer user_data)
+gboolean remove_by_id(gpointer key, gpointer value, gpointer user_data)
 {
     CacheEntry *entry = CACHE_ENTRY(value);
-    RemoveByIdData *d = (RemoveByIdData *)user_data;
-    
-    if (entry->id && (strcmp(entry->id, d->id) == 0))
-    {
+    RemoveByIdData *d = (RemoveByIdData *) user_data;
+
+    if (entry->id && (strcmp(entry->id, d->id) == 0)) {
         g_queue_unlink(d->cache->queue, entry->link);
         d->cache->current_size -= entry->size;
         unlink(entry->filename);
         return TRUE;
     }
-    
+
     return FALSE;
 }
 
-void
-file_cache_remove_by_id(FileCache *cache, gchar *id)
+void file_cache_remove_by_id(FileCache * cache, gchar * id)
 {
     RemoveByIdData d;
 
     g_assert(IS_FILE_CACHE(cache));
 
-    g_mutex_lock(cache->lock);
 
-    if (id)
-    {
+    if (id) {
         d.id = id;
         d.cache = cache;
-        g_hash_table_foreach_remove(cache->hash, remove_by_id, (gpointer)&d);
+        g_hash_table_foreach_remove(cache->hash, remove_by_id,
+                                    (gpointer) & d);
     }
-    
-    g_mutex_unlock(cache->lock);
+
 }
 
-gboolean
-remove_file(gpointer key, gpointer value, gpointer user_data)
+gboolean remove_file(gpointer key, gpointer value, gpointer user_data)
 {
     CacheEntry *entry = CACHE_ENTRY(value);
     unlink(entry->filename);
     return TRUE;
 }
 
-void
-file_cache_clear(FileCache *cache)
+void file_cache_clear(FileCache * cache)
 {
     g_assert(IS_FILE_CACHE(cache));
 
-    g_mutex_lock(cache->lock);
 
     while (g_queue_pop_head(cache->queue)) ;
     g_hash_table_foreach_remove(cache->hash, remove_file, NULL);
-  
+
     cache->current_size = 0;
 
-    g_mutex_unlock(cache->lock);
 }
 
-gboolean
-file_cache_can_resize(FileCache *cache, size_t new_size)
+gboolean file_cache_can_resize(FileCache * cache, size_t new_size)
 {
     g_assert(IS_FILE_CACHE(cache));
 
     gboolean result = FALSE;
-    
-    if (new_size >= 0)
-    {
-        g_mutex_lock(cache->lock);
 
-        if (new_size > cache->max_size)
-        {
+    if (new_size >= 0) {
+
+        if (new_size > cache->max_size) {
             struct statfs info;
 
-            result = 
-                (statfs(cache->cache_dir, &info) == 0) && 
+            result =
+                (statfs(cache->cache_dir, &info) == 0) &&
                 (info.f_bavail * info.f_bsize > new_size - cache->max_size);
         } else
             result = TRUE;
 
-        g_mutex_unlock(cache->lock);
     }
-    
+
     return result;
 }
 
-void
-file_cache_resize(FileCache *cache, size_t new_size)
+void file_cache_resize(FileCache * cache, size_t new_size)
 {
     g_assert(IS_FILE_CACHE(cache));
-    
-    if (new_size >= 0)
-    {
-        g_mutex_lock(cache->lock);
 
-        if (!new_size)
-        {
+    if (new_size >= 0) {
+
+        if (!new_size) {
             //remove the entire cache
             while (g_queue_pop_head(cache->queue)) ;
             g_hash_table_foreach_remove(cache->hash, remove_file, NULL);
         } else {
             //remove the excess elements from the cache if needed
             if (cache->current_size > new_size)
-                remove_unwanted_entries(cache, cache->current_size - new_size);
+                remove_unwanted_entries(cache,
+                                        cache->current_size - new_size);
         }
         cache->max_size = new_size;
 
-        g_mutex_unlock(cache->lock);
     }
 }
 
-size_t file_cache_size(FileCache *cache)
+size_t file_cache_size(FileCache * cache)
 {
     g_assert(IS_FILE_CACHE(cache));
 
     return cache->max_size;
 }
 
-static gchar *
-strip_url(const gchar *url)
+static gchar *strip_url(const gchar * url)
 {
-    if (!url) return NULL;
+    if (!url)
+        return NULL;
 
     gchar *result = NULL;
     gchar *p = strcasestr(url, "//www.");
-    if (p && p-url < 8) {
+    if (p && p - url < 8) {
         gchar buf[10];
-        strncpy(buf, url, p-url+2);
-        buf[p-url+2] = 0;
-        result = g_strconcat(buf, p+6, NULL);
-    } else 
+        strncpy(buf, url, p - url + 2);
+        buf[p - url + 2] = 0;
+        result = g_strconcat(buf, p + 6, NULL);
+    } else
         result = g_strdup(url);
 
     return result;
@@ -562,122 +519,129 @@ strip_url(const gchar *url)
 
 
 gpointer
-file_cache_find(FileCache *cache, const gchar *lurl, size_t *size,gboolean increase_statistic)
+file_cache_find(FileCache * cache, const gchar * lurl, size_t * size,
+                gboolean increase_statistic)
 {
     gpointer result = NULL;
     CacheEntry *entry = NULL;
     gint fsize;
     gint cpos;
-    gint fd=0,fdnew=0;
+    gint fd = 0, fdnew = 0;
     gint len;
     gchar *url = strip_url(lurl);
-    gchar *tmp=NULL;
-    gboolean rename_needed=FALSE;
+    gchar *tmp = NULL;
+    gboolean rename_needed = FALSE;
 
     g_assert(IS_FILE_CACHE(cache));
 
-//    ULOG_DEBUG("\n\n\n\n#####Cache find: %s, %d", url, cache->max_size);
-    g_mutex_lock(cache->lock);
-    
-    if (url && cache->max_size &&(entry = g_hash_table_lookup(cache->hash, url)))
-    {
+    //    ULOG_DEBUG("\n\n\n\n#####Cache find: %s, %d", url, cache->max_size);
+
+    if (url && cache->max_size
+        && (entry = g_hash_table_lookup(cache->hash, url))) {
         entry->refcount++;
-        if (increase_statistic)
-        {
-          tmp = g_strconcat(cache->cache_dir,
-                          G_DIR_SEPARATOR_S,
-                          "chXXXXXX", 0);
-          fdnew = mkstemp(tmp);
-          if (fdnew!=-1)
-          {
-            GnomeVFSResult copy_result;
-            GnomeVFSURI *src=NULL,*dest=NULL;
-            gchar *src_uri=NULL,*dest_uri=NULL;
-            close(fdnew);
-            dest_uri=gnome_vfs_get_uri_from_local_path(tmp);
-            src_uri=gnome_vfs_get_uri_from_local_path(entry->filename);
-            src=gnome_vfs_uri_new(src_uri);
-            dest=gnome_vfs_uri_new(dest_uri);
-            copy_result=gnome_vfs_xfer_uri(src,dest,GNOME_VFS_XFER_DEFAULT,GNOME_VFS_XFER_ERROR_MODE_ABORT,GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,NULL,NULL);
-            if (copy_result==GNOME_VFS_OK)
-            {
-              if ((fd=open(tmp, O_RDWR))!=-1)
-              {
-                rename_needed=TRUE;
-              }
-              else
-              {//unable to open
-                increase_statistic=FALSE;
-                unlink(tmp);
-                fd = open(entry->filename, O_RDWR);
-              }
-              
-            }
-            else
-            {//no more space to copy the file
-              increase_statistic=FALSE;
-              unlink(tmp);
-              fd = open(entry->filename, O_RDWR);
-            }
-            
-          }
-          else
-          {// now more space to open the file
-            increase_statistic=FALSE;
-            fd = open(entry->filename, O_RDWR);
-          }
-        }
-        else
-        {//not needed to modify the file, we will just read that
-          fd = open(entry->filename, O_RDWR);
-        }
-//    ULOG_DEBUG("#####Cache find: found");
-        if (fd!=-1)
-        {
-            fsize = lseek(fd, 0, SEEK_END);
-            lseek(fd, sizeof(MAGICHEAD) + 
-                      sizeof(gint) + strlen(url) +
-                      sizeof(gint) + (entry->id ? strlen(entry->id) : 0),
-                  SEEK_SET);
-            //write the usage count back to the file
-            if (((!increase_statistic)&&((cpos = lseek(fd, sizeof(GTimeVal)+sizeof(gint), SEEK_CUR)) <= fsize))||
-              (write_safe(fd, &entry->refcount, sizeof(gint)) &&
-                ((cpos = lseek(fd, sizeof(GTimeVal), SEEK_CUR)) <= fsize)))
-            {
-                len = fsize - cpos;
-                if (size) 
-                    *size = len;
-                result = (gpointer) g_try_malloc(len);
-                if (result)
-                {
-                    read_safe(fd, result, len);
-                    close(fd);
-                    if (rename_needed)
-                    {//deleting old file, rename tempfile for that
-                      unlink(entry->filename);
-                      rename(tmp,entry->filename);
+        if (increase_statistic) {
+            tmp = g_strconcat(cache->cache_dir,
+                              G_DIR_SEPARATOR_S, "chXXXXXX", 0);
+            fdnew = mkstemp(tmp);
+            if (fdnew != -1) {
+                GnomeVFSResult copy_result;
+                GnomeVFSURI *src = NULL, *dest = NULL;
+                gchar *src_uri = NULL, *dest_uri = NULL;
+                GnomeVFSFileInfo *finfo = NULL;
+                finfo = gnome_vfs_file_info_new();
+                close(fdnew);
+                dest_uri = gnome_vfs_get_uri_from_local_path(tmp);
+                src_uri = gnome_vfs_get_uri_from_local_path(entry->filename);
+                src = gnome_vfs_uri_new(src_uri);
+                dest = gnome_vfs_uri_new(dest_uri);
+                copy_result =
+                    gnome_vfs_get_file_info_uri(src, finfo,
+                                                GNOME_VFS_FILE_INFO_DEFAULT);
+                if (copy_result != GNOME_VFS_OK
+                    || finfo->type != GNOME_VFS_FILE_TYPE_REGULAR) {
+                    g_warning("Selected cache content is not correct!!!");
+                    g_free(src_uri);
+                    g_free(dest_uri);
+                    gnome_vfs_uri_unref(src);
+                    gnome_vfs_uri_unref(dest);
+                    gnome_vfs_file_info_unref(finfo);
+                    g_free(tmp);
+                    return NULL;
+                }
+                gnome_vfs_file_info_unref(finfo);
+                copy_result =
+                    gnome_vfs_xfer_uri(src, dest, GNOME_VFS_XFER_DEFAULT,
+                                       GNOME_VFS_XFER_ERROR_MODE_ABORT,
+                                       GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+                                       NULL, NULL);
+                if (copy_result == GNOME_VFS_OK) {
+                    if ((fd = open(tmp, O_RDWR)) != -1) {
+                        rename_needed = TRUE;
+                    } else {    //unable to open
+                        increase_statistic = FALSE;
+                        unlink(tmp);
+                        fd = open(entry->filename, O_RDWR);
                     }
 
-//    ULOG_DEBUG("#####Cache find: loaded");
-                    g_mutex_unlock(cache->lock);
+                } else {        //no more space to copy the file
+                    increase_statistic = FALSE;
+                    unlink(tmp);
+                    fd = open(entry->filename, O_RDWR);
+                }
+                g_free(src_uri);
+                g_free(dest_uri);
+                gnome_vfs_uri_unref(src);
+                gnome_vfs_uri_unref(dest);
+            } else {            // now more space to open the file
+                increase_statistic = FALSE;
+                fd = open(entry->filename, O_RDWR);
+            }
+        } else {                //not needed to modify the file, we will just read that
+            fd = open(entry->filename, O_RDWR);
+        }
+        //    ULOG_DEBUG("#####Cache find: found");
+        if (fd != -1) {
+            fsize = lseek(fd, 0, SEEK_END);
+            lseek(fd, sizeof(MAGICHEAD) +
+                  sizeof(gint) + strlen(url) +
+                  sizeof(gint) + (entry->id ? strlen(entry->id) : 0),
+                  SEEK_SET);
+            //write the usage count back to the file
+            if (((!increase_statistic)
+                 &&
+                 ((cpos =
+                   lseek(fd, sizeof(GTimeVal) + sizeof(gint),
+                         SEEK_CUR)) <= fsize))
+                || (write_safe(fd, &entry->refcount, sizeof(gint))
+                    && ((cpos = lseek(fd, sizeof(GTimeVal), SEEK_CUR)) <=
+                        fsize))) {
+                len = fsize - cpos;
+                if (size)
+                    *size = len;
+                result = (gpointer) g_try_malloc(len);
+                if (result) {
+                    read_safe(fd, result, len);
+                    close(fd);
+                    if (rename_needed) {    //deleting old file, rename tempfile for that
+                        unlink(entry->filename);
+                        rename(tmp, entry->filename);
+                    }
+                    //    ULOG_DEBUG("#####Cache find: loaded");
                     g_free(url);
+                    g_free(tmp);
                     return result;
                 }
             }
-            
-            if (rename_needed)
-            {//temporary file was created, only that was modified. Deleting only that
-              unlink(tmp);
-            }
-            else
-            {
 
-            //damaged file ... remove it
-            unlink(entry->filename);
+            if (rename_needed) {    //temporary file was created, only that was modified. Deleting only that
+                unlink(tmp);
+            } else {
+
+                //damaged file ... remove it
+                unlink(entry->filename);
             }
         }
-        
-//    ULOG_DEBUG("#####Cache find: something wrong");
+        //    ULOG_DEBUG("#####Cache find: something wrong");
         //damaged hash entry ... remove it
         g_queue_unlink(cache->queue, entry->link);
         g_hash_table_remove(cache->hash, url);
@@ -686,31 +650,26 @@ file_cache_find(FileCache *cache, const gchar *lurl, size_t *size,gboolean incre
     if (size)
         *size = 0;
 
-    g_mutex_unlock(cache->lock);
 
     g_free(url);
-
+    g_free(tmp);
     return NULL;
 }
 
-gboolean
-file_cache_exists(FileCache *cache, const gchar *lurl)
+gboolean file_cache_exists(FileCache * cache, const gchar * lurl)
 {
     g_assert(IS_FILE_CACHE(cache));
 
     gchar *url = strip_url(lurl);
-    g_mutex_lock(cache->lock);
     gboolean result = g_hash_table_lookup(cache->hash, url) != NULL;
-    g_mutex_unlock(cache->lock);
     g_free(url);
     return result;
 }
 
-void 
-cache_entry_destroy(gpointer data)
+void cache_entry_destroy(gpointer data)
 {
     CacheEntry *entry = CACHE_ENTRY(data);
-    
+
     g_free(entry->id);
     g_free(entry->filename);
     g_free(entry->url);
@@ -718,13 +677,13 @@ cache_entry_destroy(gpointer data)
     g_free(entry);
 }
 
-gint 
-cache_entry_cmp(gconstpointer a, gconstpointer b, gpointer user_data)
+gint cache_entry_cmp(gconstpointer a, gconstpointer b, gpointer user_data)
 {
     const CacheEntry *c1 = a;
     const CacheEntry *c2 = b;
 
-    if (a == b) return 0;
+    if (a == b)
+        return 0;
     if (c1->time.tv_sec == c2->time.tv_sec)
         return c1->time.tv_usec - c2->time.tv_usec;
     return c1->time.tv_sec - c2->time.tv_sec;
