@@ -22,8 +22,6 @@
 
 #include "state_save.h"
 #include "conf.h"
-#include "ui_feedlist.h"
-#include "ui_mainwindow.h"
 
 #include "gtkhtml/gtkhtml_plugin.h"
 #include <stdlib.h>
@@ -35,13 +33,9 @@
 
 typedef gchar *gchar_ptr;
 
-extern AppData* app_data;
+extern AppData *app_data;
 extern nodePtr displayed_node;
 
-/************************************************************************/
-/*                        PRIVATE FUNCTIONS                             */
-/************************************************************************/
-
 /** Searches the tree store for a node
   *
   * @param store the store to search in
@@ -54,9 +48,9 @@ extern nodePtr displayed_node;
   */
 static
 gboolean search_store(GtkTreeModel * store,
-		      GtkTreeIter const *start_iter,
-		      GtkTreeIter * result_iter,
-		      gchar ** path, gint cur_depth, gint depth)
+                      GtkTreeIter const *start_iter,
+                      GtkTreeIter * result_iter,
+                      gchar ** path, gint cur_depth, gint depth)
 {
     GtkTreeIter cur_iter;
     GtkTreeIter child_iter;
@@ -64,92 +58,74 @@ gboolean search_store(GtkTreeModel * store,
     nodePtr node = NULL;
     GValue value;
     const gchar *id = NULL;
-    /* DEBUG START */
-    GtkTreePath *tmp_path = NULL;
-    gchar *tmp_str = NULL;
-    /* DEBUG END */
-
-    ULOG_DEBUG("%s cur_depth = %d", __FUNCTION__, cur_depth);
 
     *result_iter = *start_iter;
     if (depth <= 0) {
-	return FALSE;
+        return FALSE;
     }
 
     cur_iter = *start_iter;
     if (cur_depth == 1) {
-	if (depth > 1) {
-	    iter_result = gtk_tree_model_iter_children(store,
-						       &child_iter,
-						       &cur_iter);
-	    if (iter_result) {
-	        ULOG_DEBUG("searching store with store: %p child_iter: %p",store,&child_iter);
-		ULOG_DEBUG("result_iter: %p path: %p cur_depth: %d depth: %d",result_iter,path,cur_depth,depth);
-		return
-		    search_store(store,
-				 &child_iter,
-				 result_iter, path, cur_depth + 1, depth);
-	    } else {
-		return FALSE;
-	    }
-	} else {
-	    return TRUE;
-	}
+        if (depth > 1) {
+            iter_result = gtk_tree_model_iter_children(store,
+                                                       &child_iter,
+                                                       &cur_iter);
+            if (iter_result) {
+                g_debug("searching store with store: %p child_iter: %p",
+                           store, &child_iter);
+                g_debug("result_iter: %p path: %p cur_depth: %d depth: %d",
+                           result_iter, path, cur_depth, depth);
+                return search_store(store, &child_iter, result_iter, path,
+                                    cur_depth + 1, depth);
+            } else {
+                return FALSE;
+            }
+        } else {
+            return TRUE;
+        }
     } else {
-	memset(&value, 0, sizeof(value));
-	while (TRUE) {
-	    gtk_tree_model_get_value(store, &cur_iter, FS_PTR, &value);
-	    node = (nodePtr) g_value_peek_pointer(&value);
+        memset(&value, 0, sizeof(value));
+        while (TRUE) {
+            gtk_tree_model_get_value(store, &cur_iter, FS_PTR, &value);
+            node = (nodePtr) g_value_peek_pointer(&value);
 
-	    if(node != NULL)
-            {
-		if (node->type == FST_FEED || node->type == FST_VFOLDER) {
-			id = ((feedPtr) node)->id;
-		} else if (node->type == FST_FOLDER) {
-			id = ((folderPtr) node)->id;
-		} else {
-		        ULOG_ERR("unknown node type (%d)", node->type);
-			id = NULL;
-		}
+            if (node != NULL) {
+                if (node->type == FST_FEED || node->type == FST_VFOLDER) {
+                    id = ((feedPtr) node)->id;
+                } else if (node->type == FST_FOLDER) {
+                    id = ((folderPtr) node)->id;
+                } else {
+                    g_warning("unknown node type (%d)", node->type);
+                    id = NULL;
+                }
 
-		if (id != NULL && strcmp(id, path[cur_depth - 1]) == 0) {
-			ULOG_DEBUG("id: %s", id);
-			if (cur_depth < depth) {
-			iter_result = gtk_tree_model_iter_children(store,
-								&child_iter,
-								&cur_iter);
-			if (iter_result) {
-				g_value_unset(&value);
-				return
-				search_store(store,
-						&child_iter,
-						result_iter,
-						path, cur_depth + 1, depth);
-			} else {
-				return FALSE;
-			}
-			}
-			ULOG_DEBUG("found");
-			*result_iter = cur_iter;
-			/* DEBUG START */
-			tmp_path = gtk_tree_model_get_path(store, &cur_iter);
-			tmp_str = gtk_tree_path_to_string(tmp_path);
-			ULOG_DEBUG("path: %s", tmp_str);
-			g_free(tmp_str);
-			tmp_str = NULL;
-			gtk_tree_path_free(tmp_path);
-			tmp_path = NULL;
-			/* DEBUG END */
-			g_value_unset(&value);
-			return TRUE;
-		}
-	    }
-	    g_value_unset(&value);
-	    iter_result = gtk_tree_model_iter_next(store, &cur_iter);
-	    if (!iter_result) {
-		break;
-	    }
-	}
+                if (id != NULL && strcmp(id, path[cur_depth - 1]) == 0) {
+                    if (cur_depth < depth) {
+                        iter_result = gtk_tree_model_iter_children(store,
+                                                                   &child_iter,
+                                                                   &cur_iter);
+                        if (iter_result) {
+                            g_value_unset(&value);
+                            return
+                                search_store(store,
+                                             &child_iter,
+                                             result_iter,
+                                             path, cur_depth + 1, depth);
+                        } else {
+                            return FALSE;
+                        }
+                    }
+                    *result_iter = cur_iter;
+                    g_value_unset(&value);
+                    return TRUE;
+                }
+            }
+            g_value_unset(&value);
+            iter_result = gtk_tree_model_iter_next(store, &cur_iter);
+            if (!iter_result) {
+                break;
+            }
+        }
     }
     return FALSE;
 }
@@ -167,17 +143,13 @@ gboolean search_store(GtkTreeModel * store,
 static void check_read_error(GError ** error, gboolean * result)
 {
     if (*error != NULL) {
-	ULOG_ERR("Error reading field (%s)\n", (*error)->message);
-	g_error_free(*error);
-	*error = NULL;
-	*result = FALSE;
+        g_warning("Error reading field (%s)\n", (*error)->message);
+        g_error_free(*error);
+        *error = NULL;
+        *result = FALSE;
     }
 }
 
-/************************************************************************/
-/*                        PUBLIC FUNCTIONS                              */
-/************************************************************************/
-
 void init_app_state(AppState * app_state)
 {
     g_assert(app_state != NULL);
@@ -210,9 +182,7 @@ void destroy_app_state(AppState * app_state)
     g_assert(app_state != NULL);
 
     /* Free the fields of app_state. */
-    /*if (app_state->current_feed_depth > 0) {*/
     g_strfreev(app_state->current_feed);
-    /*}*/
 
     /* Free app_state. */
     g_free(app_state);
@@ -233,62 +203,61 @@ void construct_app_state(AppState * app_state)
     nodePtr node = NULL;
     gboolean iter_result = FALSE;
 
-    ULOG_DEBUG("construst_app_state");
-    
     g_assert(app_state != NULL);
-    
-    if(displayed_node != NULL) {
+
+    if (displayed_node != NULL) {
         /* Fill the fields of app_state using the values from the
-           UI variables.
-        */
+         * UI variables.
+         */
         gtk_tree_view_get_cursor(GTK_TREE_VIEW(feedlist), &path, NULL);
         if (path != NULL) {
-	    gtk_tree_model_get_iter(GTK_TREE_MODEL(feedmodel), &iter, path);
+            gtk_tree_model_get_iter(GTK_TREE_MODEL(feedmodel), &iter, path);
 
-	    ui_feedlist_convert_visible_iter_to_store_iter(&cur_iter, &iter);
+            ui_feedlist_convert_visible_iter_to_store_iter(&cur_iter, &iter);
 
-	    index = 0;
-	    while (index < STATE_MAX_PATH_DEPTH) {
-	        memset(&value, 0, sizeof(value));
+            index = 0;
+            while (index < STATE_MAX_PATH_DEPTH) {
+                memset(&value, 0, sizeof(value));
 
-	        gtk_tree_model_get_value(GTK_TREE_MODEL(feedstore),
-		    		         &cur_iter, FS_PTR, &value);
+                gtk_tree_model_get_value(GTK_TREE_MODEL(feedstore),
+                                         &cur_iter, FS_PTR, &value);
 
-	        node = (nodePtr) g_value_peek_pointer(&value);
-	    
-	        if(node == NULL) {
-	            id = NULL;
-	        } else if (node->type == FST_FEED || node->type == FST_VFOLDER) {
- 		    id = ((feedPtr) node)->id;
-	        } else if (node->type == FST_FOLDER) {
-		    id = ((folderPtr) node)->id;
-	        } else {
-		    ULOG_ERR("unknown node type (%d)", node->type);
-		    id = NULL;
-	        }
-	        if (id != NULL) {
-		    path_arr[index] = g_strdup(id);
-	        } else {
-		    path_arr[index] = g_strdup("UNKNOWN");
-	        }
-	        g_value_unset(&value);
-	        iter_result =
-		    gtk_tree_model_iter_parent(GTK_TREE_MODEL(feedstore),
-					       &new_iter, &cur_iter);
-	        cur_iter = new_iter;
-	        index++;
-	        if (!iter_result) {
-		    /* At top level. */
-		    break;
-	        }
-	    }
-	    gtk_tree_path_free(path);
-	    count = index;
+                node = (nodePtr) g_value_peek_pointer(&value);
+
+                if (node == NULL) {
+                    id = NULL;
+                } else if (node->type == FST_FEED
+                           || node->type == FST_VFOLDER) {
+                    id = ((feedPtr) node)->id;
+                } else if (node->type == FST_FOLDER) {
+                    id = ((folderPtr) node)->id;
+                } else {
+                    g_warning("unknown node type (%d)", node->type);
+                    id = NULL;
+                }
+                if (id != NULL) {
+                    path_arr[index] = g_strdup(id);
+                } else {
+                    path_arr[index] = g_strdup("UNKNOWN");
+                }
+                g_value_unset(&value);
+                iter_result =
+                    gtk_tree_model_iter_parent(GTK_TREE_MODEL(feedstore),
+                                               &new_iter, &cur_iter);
+                cur_iter = new_iter;
+                index++;
+                if (!iter_result) {
+                    /* At top level. */
+                    break;
+                }
+            }
+            gtk_tree_path_free(path);
+            count = index;
         } else {
- 	    count = 0;
+            count = 0;
         }
         for (index = 0; index < count; index++) {
-	    app_state->current_feed[index] = path_arr[count - index - 1];
+            app_state->current_feed[index] = path_arr[count - index - 1];
         }
         app_state->current_feed[count] = NULL;
         app_state->current_feed_depth = count;
@@ -296,12 +265,11 @@ void construct_app_state(AppState * app_state)
         app_state->current_feed[0] = NULL;
         app_state->current_feed_depth = 0;
     }
-    
+
     g_assert(app_data != NULL);
     g_assert(app_data->app_ui_data != NULL);
-    
-    app_state->fullscreen = (hildon_appview_get_fullscreen
-	      (hildon_app_get_appview(app_data->app_ui_data->app)));
+
+    app_state->fullscreen = app_data->app_ui_data->fullscreen;
 }
 
 
@@ -314,83 +282,63 @@ void update_app_state(const AppState * app_state)
     gboolean search_result = FALSE;
     nodePtr node = NULL;
     folderPtr root_folder = NULL;
-    gint index = 0;
-    gchar *tmp_str = NULL;
-
-    ULOG_DEBUG(__FUNCTION__);
 
     g_assert(app_state != NULL);
 
     g_assert(feedstore != NULL && feedlist != NULL);
 
 
-    if(app_state->current_feed_depth > 0) {
+    if (app_state->current_feed_depth > 0) {
         /*
-           Update the UI variables.
-        */
-
-        /* DEBUG START */
-        for (index = 0; index < app_state->current_feed_depth; index++) {
-	    ULOG_DEBUG("%d: [%s]", index, app_state->current_feed[index]);
-        }
-        /* DEBUG END */
+         * Update the UI variables.
+         */
 
         root_folder = ui_feedlist_get_root_folder();
         if (root_folder == NULL) {
-	    ULOG_ERR("root folder not set\n");
+            g_warning("root folder not set");
         }
         if (root_folder->ui_data == NULL) {
-	    ULOG_ERR("error in root folder (ui_data NULL)\n");
+            g_warning("error in root folder (ui_data NULL)");
         }
         root_iter = ((ui_data *) (root_folder->ui_data))->row;
         search_result = search_store(GTK_TREE_MODEL(feedstore),
-				     &root_iter,
-				     &result_iter,
-				     app_state->current_feed,
-				     1, app_state->current_feed_depth);
-				 
-        ULOG_DEBUG("search result: %d",search_result);				 
+                                     &root_iter,
+                                     &result_iter,
+                                     app_state->current_feed,
+                                     1, app_state->current_feed_depth);
+
         if (search_result) {
-	    ui_feedlist_convert_store_iter_to_visible_iter(&visible_iter,
-						           &result_iter);
-	    path = gtk_tree_model_get_path(feedmodel, &visible_iter);
-	    /* DEBUG START */
-	    tmp_str = gtk_tree_path_to_string(path);
-	    ULOG_DEBUG("path: %s\n", tmp_str);
-	    g_free(tmp_str);
-	    tmp_str = NULL;
-	    /* DEBUG END */
-	    gtk_tree_view_set_cursor(GTK_TREE_VIEW(feedlist),
-				     path, NULL, FALSE);
-	    gtk_widget_grab_focus(GTK_WIDGET(feedlist));
-	    node = ui_feedlist_get_selected();
-	    if (node != NULL) {
-	        ULOG_DEBUG("selected node is set");
-	        if (node->type == FST_FEED || node->type == FST_FOLDER) {
-		    ULOG_DEBUG("and it's a feed or folder");
-		    ui_feedlist_load_selected(node);
-		    app_data->app_ui_data->vertical_scroll_window_position = app_state->vertical_scroll_window_position;
-		    //g_idle_add((GSourceFunc)textview_set_vertical_scroll_position, NULL);
-	        }
-	    } else {
-	        ULOG_ERR("no valid selection found\n");
-	    }
-	    gtk_tree_path_free(path);
+            ui_feedlist_convert_store_iter_to_visible_iter(&visible_iter,
+                                                           &result_iter);
+            path = gtk_tree_model_get_path(feedmodel, &visible_iter);
+            gtk_tree_view_set_cursor(GTK_TREE_VIEW(feedlist),
+                                     path, NULL, FALSE);
+            gtk_widget_grab_focus(GTK_WIDGET(feedlist));
+            node = ui_feedlist_get_selected();
+            if (node != NULL) {
+                if (node->type == FST_FEED || node->type == FST_FOLDER) {
+                    ui_feedlist_load_selected(node);
+                    app_data->app_ui_data->vertical_scroll_window_position =
+                        app_state->vertical_scroll_window_position;
+                }
+            } else {
+                g_warning("no valid selection found");
+            }
+            gtk_tree_path_free(path);
         } else {
-	    ULOG_ERR("selected item not found\n");
+           g_warning("selected item not found");
         }
     }
-    
+
     g_assert(app_data != NULL);
     g_assert(app_data->app_ui_data != NULL);
-    
-//    app_state->fullscreen = FALSE;
+
     ui_set_fullscreen_state(app_data->app_ui_data, FALSE, TRUE);
 }
 
 
 StateSaveResultCode reader_save_state(AppData * app_data,
-				      AppState * app_state)
+                                      AppState * app_state)
 {
     GKeyFile *key_file = NULL;
     gchar *contents = NULL;
@@ -413,12 +361,11 @@ StateSaveResultCode reader_save_state(AppData * app_data,
 
     /* Handle errors. */
     if (err != NULL) {
-	ULOG_ERR("error saving application state (%s)\n",
-		 err->message);
-	g_free(contents);
-	g_error_free(err);
-	err = NULL;
-	return ST_ERR_KEY_FILE;
+        g_warning("error saving application state (%s)", err->message);
+        g_free(contents);
+        g_error_free(err);
+        err = NULL;
+        return ST_ERR_KEY_FILE;
     }
 
     /* Save contents to the state file. */
@@ -441,31 +388,26 @@ GKeyFile *save_app_state_to_key_file(AppState * app_state)
     g_assert(key_file != NULL);
     /* Save the fields of app_data to the key file. */
     /* The third argument is typecasted in order to avoid
-       a compiler warning.
+     * a compiler warning.
      */
     g_key_file_set_string_list(key_file,
-			       STATE_KEY_FILE_GROUP,
-			       STATE_KEY_CURRENT_FEED,
-			       (const char *const *) app_state->
-			       current_feed,
-			       app_state->current_feed_depth);
-			       
+                               STATE_KEY_FILE_GROUP,
+                               STATE_KEY_CURRENT_FEED,
+                               (const char *const *) app_state->
+                               current_feed, app_state->current_feed_depth);
+
     g_key_file_set_boolean(key_file,
                            STATE_KEY_FILE_GROUP,
-                           STATE_KEY_FULLSCREEN,                  
-                           app_state->fullscreen);                  
-			   
-    g_key_file_set_integer (key_file,
-                            STATE_KEY_FILE_GROUP,
-                            STATE_KEY_SCROLL_POSITION,
-                            1); //textview_get_vertical_scroll_position());
-			    			       			   
+                           STATE_KEY_FULLSCREEN, app_state->fullscreen);
+
+    g_key_file_set_integer(key_file, STATE_KEY_FILE_GROUP, STATE_KEY_SCROLL_POSITION, 1);
+
     return key_file;
 }
 
 
 StateSaveResultCode do_save_state(osso_context_t * osso,
-				  const gchar * contents)
+                                  const gchar * contents)
 {
     osso_state_t state;
     gint contents_length = 0;
@@ -473,17 +415,14 @@ StateSaveResultCode do_save_state(osso_context_t * osso,
     osso_return_t ret = OSSO_ERROR;
     gchar buffer[STATE_FILE_LENGTH];
 
-    ULOG_DEBUG(__FUNCTION__);
-
     g_assert(osso != NULL && contents != NULL);
 
     /* Check if the contents are too long. */
     contents_length = strlen(contents);
     if (contents_length >= STATE_FILE_LENGTH) {
-	ULOG_ERR(
-		 "Error writing state file. Too long data (%d).\n",
-		 contents_length);
-	return ST_ERR_TOO_LONG;
+        g_warning("Error writing state file. Too long data (%d).",
+                 contents_length);
+        return ST_ERR_TOO_LONG;
     }
 
     /* Initialize the osso_state_t struct. */
@@ -500,11 +439,10 @@ StateSaveResultCode do_save_state(osso_context_t * osso,
     ret = osso_state_write(osso, &state);
 
     if (ret != OSSO_OK) {
-	ULOG_ERR(
-		 "Writing state file failed. Error %d.", (gint) ret);
-	result = ST_ERR_WRITE;
+        g_warning("Writing state file failed. Error %d.", (gint) ret);
+        result = ST_ERR_WRITE;
     } else {
-	result = ST_SUCCESS;
+        result = ST_SUCCESS;
     }
 
     return result;
@@ -520,8 +458,6 @@ reader_load_state(AppData * app_data, AppState * app_state)
     StateSaveResultCode ret_load = ST_ERR_READ;
     gboolean ret = FALSE;
 
-    ULOG_DEBUG(__FUNCTION__);
-
     g_assert(app_data != NULL && app_state != NULL);
 
     /* Load the state file contents as string. */
@@ -530,7 +466,7 @@ reader_load_state(AppData * app_data, AppState * app_state)
 
     /* Check errors. */
     if (ret_load != ST_SUCCESS) {
-	return ret_load;
+        return ret_load;
     }
 
     /* Create a key file. */
@@ -538,17 +474,16 @@ reader_load_state(AppData * app_data, AppState * app_state)
 
     /* Load key file from the state file contents. */
     ret = g_key_file_load_from_data(key_file,
-				    buffer,
-				    strlen(buffer), G_KEY_FILE_NONE, &err);
+                                    buffer,
+                                    strlen(buffer), G_KEY_FILE_NONE, &err);
 
     /* Check errors. */
     if ((!ret) || err != NULL) {
-	ULOG_ERR(
-		 "Error loading key file from state file contents.\n"
-		 "error: %s\n", err->message);
-	g_error_free(err);
-	err = NULL;
-	return ST_ERR_KEY_FILE;
+        g_warning("Error loading key file from state file contents.\n"
+                 "error: %s", err->message);
+        g_error_free(err);
+        err = NULL;
+        return ST_ERR_KEY_FILE;
     }
 
     /* Load app_state from the key file. */
@@ -566,8 +501,6 @@ StateSaveResultCode do_load_state(osso_context_t * osso, gchar * buffer)
     osso_state_t state;
     osso_return_t ret = OSSO_ERROR;
 
-    ULOG_DEBUG(__FUNCTION__);
-
     g_assert(osso != NULL && buffer != NULL);
 
     memset(&state, 0, sizeof(state));
@@ -578,21 +511,20 @@ StateSaveResultCode do_load_state(osso_context_t * osso, gchar * buffer)
 
     /* Check errors. */
     if (ret == OSSO_ERROR_NO_STATE) {
-	ULOG_INFO("Reading state file failed. No state.\n");
-	return ST_ERR_NO_SAVED_STATE;
+        g_debug("Reading state file failed. No state.");
+        return ST_ERR_NO_SAVED_STATE;
     } else if (ret == OSSO_ERROR_STATE_SIZE) {
-	ULOG_INFO("Reading state file failed. Empty state.\n");
-	return ST_ERR_NO_SAVED_STATE;
+        g_debug("Reading state file failed. Empty state.");
+        return ST_ERR_NO_SAVED_STATE;
     } else if (ret != OSSO_OK) {
-	ULOG_ERR("Reading state file failed. Error %d.\n",
-		 (gint) ret);
-	return ST_ERR_READ;
+        g_warning("Reading state file failed. Error %d.", (gint) ret);
+        return ST_ERR_READ;
     }
 
     if (((gchar *) state.state_data)[STATE_FILE_LENGTH - 1]
-	!= 0) {
-	ULOG_ERR("Reading state file failed. Corrupted data.");
-	return ST_ERR_READ;
+        != 0) {
+        g_warning("Reading state file failed. Corrupted data.");
+        return ST_ERR_READ;
     }
 
     return ST_SUCCESS;
@@ -600,7 +532,7 @@ StateSaveResultCode do_load_state(osso_context_t * osso, gchar * buffer)
 
 
 gboolean load_app_state_from_key_file(AppState * app_state,
-				      GKeyFile * key_file)
+                                      GKeyFile * key_file)
 {
     GError *err = NULL;
     gboolean result = TRUE;
@@ -610,27 +542,25 @@ gboolean load_app_state_from_key_file(AppState * app_state,
     /* Load the fields of app_state from the key file. */
     g_strfreev(app_state->current_feed);
     app_state->current_feed =
-	g_key_file_get_string_list(key_file,
-				   STATE_KEY_FILE_GROUP,
-				   STATE_KEY_CURRENT_FEED,
-				   &(app_state->current_feed_depth), &err);
+        g_key_file_get_string_list(key_file,
+                                   STATE_KEY_FILE_GROUP,
+                                   STATE_KEY_CURRENT_FEED,
+                                   &(app_state->current_feed_depth), &err);
     check_read_error(&err, &result);
-    
+
     app_state->fullscreen =
         g_key_file_get_boolean(key_file,
-	                       STATE_KEY_FILE_GROUP,
-			       STATE_KEY_FULLSCREEN,
-			       &err);
+                               STATE_KEY_FILE_GROUP,
+                               STATE_KEY_FULLSCREEN, &err);
     check_read_error(&err, &result);
-    
-    app_state->vertical_scroll_window_position = 
+
+    app_state->vertical_scroll_window_position =
         g_key_file_get_integer(key_file,
                                STATE_KEY_FILE_GROUP,
-			       STATE_KEY_SCROLL_POSITION,
-			       &err);
-			       			   
+                               STATE_KEY_SCROLL_POSITION, &err);
+
     check_read_error(&err, &result);
-    			       
+
     return result;
 }
 
@@ -649,9 +579,8 @@ StateSaveResultCode reset_state_file(osso_context_t * osso)
     /* Open the state file. */
     ret = osso_state_write(osso, &state);
     if (ret != OSSO_OK) {
-	ULOG_ERR(
-		 "Resetting state file failed. Error %d.\n", (gint) ret);
-	return ST_ERR_WRITE;
+        g_warning("Resetting state file failed. Error %d.", (gint) ret);
+        return ST_ERR_WRITE;
     }
 
     return ST_SUCCESS;
