@@ -29,17 +29,76 @@
 #include "ui_folder.h"
 #include "ui_mainwindow.h"
 
-#include <hildon-widgets/gtk-infoprint.h>
+#include "debug_new.h"
+#include <hildon/hildon-banner.h>
 #include <osso-log.h>
 
 static GtkWidget *foldernamedialog = NULL;
 extern AppData *app_data;
 
-gint  ui_get_marked_from_iter(GtkTreeIter * iter);
+gint ui_get_marked_from_iter(GtkTreeIter * iter);
+void ui_folder_empty_check(folderPtr folder);
+void ui_folder_remove(gpointer callback_data, guint callback_action,
+                      GtkWidget * widget);
+
+
+/** Looks up a folder id from the folder tree
+  *
+  * @param from the iter to start the search from
+  * @param id of the folder to look for
+  * @return pointer to the folder
+  */
+folderPtr ui_folder_lookup_by_id(GtkTreeIter *from, gchar *id)
+{
+    GtkTreeIter iter;
+    gboolean valid = FALSE;
+    nodePtr node = NULL; 
+    GtkTreeModel *model = NULL;
+    folderPtr found_folder = NULL;
+
+    g_assert(NULL != feedstore);
+
+    model = GTK_TREE_MODEL(feedstore);
+
+    if (from != NULL) 
+    {
+        gtk_tree_model_get(model, from, FS_PTR, &node, -1);
+        valid = gtk_tree_model_iter_children(model, &iter, from);
+
+    } 
+    else 
+    {
+        valid = gtk_tree_model_get_iter_first(model, &iter);
+    }
+
+    while (valid) 
+    {
+        gtk_tree_model_get(model, &iter, FS_PTR, &node, -1);
+
+        if (NULL != node)
+        {
+            if (FST_FOLDER == feed_get_type((feedPtr) node))
+            {
+                gchar *current_id = NULL;
+
+                current_id = folder_get_id((folderPtr) node);
+
+                if(current_id != NULL && id != NULL)
+                {
+                    if(!strcmp(current_id, id))
+                        return (folderPtr) node;
+                }
+                found_folder = ui_folder_lookup_by_id(&iter, id);
+
+                if(found_folder)
+                    break;
+            }
+        }
+        valid = gtk_tree_model_iter_next(model, &iter);
+    }
+    return found_folder;
+}
 
-/************************************************************************/
-/*                        PRIVATE FUNCTIONS                             */
-/************************************************************************/
 
 /** Checks if a folder exists in the feed tree
   *
@@ -48,61 +107,42 @@ gint  ui_get_marked_from_iter(GtkTreeIter * iter);
   * @return TRUE if found
   * tvh: made this non-recursive
   */
-gboolean ui_folder_check_if_exists(GtkTreeIter *from, gchar *candidate)
+gboolean ui_folder_check_if_exists(GtkTreeIter * from, gchar * candidate)
 {
     GtkTreeIter iter;
     gboolean valid = FALSE;
-    nodePtr node = NULL; 
+    nodePtr node = NULL;
     GtkTreeModel *model = NULL;
-    //gboolean found = FALSE;
     GtkTreeIter root;
     g_assert(NULL != feedstore);
 
-    ULOG_DEBUG("\n\nui_folder_check_if_exists: checking..\n\n");
     model = GTK_TREE_MODEL(feedstore);
-    
-    if (from != NULL) 
-    {
+
+    if (from != NULL) {
         gtk_tree_model_get(model, from, FS_PTR, &node, -1);
         valid = gtk_tree_model_iter_children(model, &iter, from);
-                     
-    } 
-    else 
-    {
-        ULOG_DEBUG("getting the inter from root ");
+
+    } else {
         valid = gtk_tree_model_get_iter_first(model, &root);
         /*get first child of root */
-        ULOG_DEBUG("getting the first child of root ");
         valid = gtk_tree_model_iter_children(model, &iter, &root);
-
     }
 
-    while (valid) 
-    {
+    while (valid) {
         gtk_tree_model_get(model, &iter, FS_PTR, &node, -1);
-    
-        if (NULL != node) 
-        {
-            if (FST_FOLDER == feed_get_type((feedPtr) node)) 
-            {
+
+        if (NULL != node) {
+            if (FST_FOLDER == feed_get_type((feedPtr) node)) {
                 gchar *existing_title = NULL;
-            
+
                 existing_title = folder_get_title((folderPtr) node);
-                ULOG_DEBUG("ui_folder_check_if_exists: existing title = %s ", existing_title);
-                if(existing_title != NULL && candidate != NULL)
-                {
-                    if(!strcmp(existing_title, candidate))
+                if (existing_title != NULL && candidate != NULL) {
+                    if (!strcmp(existing_title, candidate))
                         return TRUE;
                 }
-                /* Not recursive 
-                    found = ui_folder_check_if_exists(&iter, candidate);
-                
-                if(found)
-                    break;
-                */
             }
         }
-    valid = gtk_tree_model_iter_next(model, &iter);
+        valid = gtk_tree_model_iter_next(model, &iter);
     }
     return FALSE;
 }
@@ -113,27 +153,9 @@ gboolean ui_folder_check_if_exists(GtkTreeIter *from, gchar *candidate)
   * @param np the folder the icon is needed for
   * @return the icon
   */
-//GdkPixbuf *ui_folder_select_icon(folderPtr np)
 GdkPixbuf *ui_folder_select_icon(gboolean expanded)
 {
-    //gboolean expanded = FALSE;
-
-    //g_assert(NULL != np);
-    //g_assert(FST_FOLDER == np->type);
-    //ULOG_DEBUG("<++++++++ui_folder_select_icon++++++++++folder = %s ++++++expanded = %s++++>",
-    //            np->title, np->expanded ? "TRUE":"FALSE");
-    //switch (np->type) {
-    //case FST_FOLDER:
-    //expanded = ui_is_folder_expanded(np);
-    //expanded = np->expanded;
-    if (TRUE == expanded)
-        return icons[ICON_FOLDER_OPEN_WITH_EMBLEM];
-    return icons[ICON_FOLDER_CLOSED_WITH_EMBLEM];
-    //default:
-    //ULOG_ERR
-    //    ("internal error! unknown entry type! cannot display appropriate icon!");
-    //return icons[ICON_RSS_NEWS_FEED];
-    //}
+    return icons[expanded ? ICON_FOLDER_OPEN_WITH_EMBLEM : ICON_FOLDER_CLOSED_WITH_EMBLEM];
 }
 
 /** Updates a folder
@@ -153,7 +175,7 @@ static void ui_folder_update_from_iter(GtkTreeIter * iter)
     model = GTK_TREE_MODEL(feedstore);
 
     gtk_tree_model_get(model, iter, FS_PTR, &ptr, -1);
-        
+
     g_assert(FST_FOLDER == ptr->type);
     g_assert(ptr != NULL);
     g_assert(ptr->ui_data);
@@ -161,42 +183,43 @@ static void ui_folder_update_from_iter(GtkTreeIter * iter)
     title = g_markup_escape_text(folder_get_title(ptr), -1);
 
     unread = 0;
-    marked =ui_get_marked_from_iter(iter) ;
+    marked = ui_get_marked_from_iter(iter);
     rc = gtk_tree_model_iter_children(model, &child, iter);
 
     while (rc) {
-     gtk_tree_model_get(model, &child, FS_UNREAD, &count,
-               FS_PTR, &childptr, -1);
-    unread += count;
-   rc = gtk_tree_model_iter_next(model, &child);
+        gtk_tree_model_get(model, &child, FS_UNREAD, &count,
+                           FS_PTR, &childptr, -1);
+        unread += count;
+        rc = gtk_tree_model_iter_next(model, &child);
     }
     ptr->markCount = marked;
 
     if (unread > 0 && marked > 0)
-    label =
-        g_strdup_printf
-        ("<span weight=\"bold\" foreground=\"%s\">%s (%d)</span>",
-         "red"/*get_logical_color(EMPTEXTCOLOR)*/, title, unread);
+        label =
+            g_strdup_printf
+            ("<span weight=\"bold\" foreground=\"%s\">%s (%d)</span>",
+             "red", title, unread);
     else if (unread > 0)
-    label = g_strdup_printf("<span weight=\"bold\" foreground=\"%s\">%s (%d)</span>",
-            "black"/*get_logical_color(DEFAULTTEXTCOLOR)*/, title, unread);
+        label =
+            g_strdup_printf
+            ("<span weight=\"bold\" foreground=\"%s\">%s (%d)</span>",
+             "black", title, unread);
 
     else if (marked > 0)
-    label =
-        g_strdup_printf
-        ("<span foreground=\"%s\">%s</span>",
-         "red"/*get_logical_color(EMPTEXTCOLOR)*/, title);
+        label =
+            g_strdup_printf
+            ("<span foreground=\"%s\">%s</span>",
+             "red", title);
     else
-    label = g_strdup_printf("<span foreground=\"%s\">%s</span>",
-                "black"/*get_logical_color(DEFAULTTEXTCOLOR)*/,
-                title);
+        label = g_strdup_printf("<span foreground=\"%s\">%s</span>",
+                                "black",
+                                title);
 
-    /* CHECK: valgrind says internal row-changed event from this leaks memory */
     gtk_tree_store_set(feedstore, iter,
-               FS_LABEL, label,
-               FS_ICON, ui_folder_select_icon(ptr->expanded),
-               FS_UNREAD, unread, -1);
-                 
+                       FS_LABEL, label,
+                       FS_ICON, ui_folder_select_icon(ptr->expanded),
+                       FS_UNREAD, unread, -1);
+
     g_free(title);
     g_free(label);
 }
@@ -226,103 +249,107 @@ void on_newfolderbtn_clicked(GtkButton * button, gpointer user_data)
 
     g_assert(newfolderdialog != NULL);
 
-    ULOG_DEBUG("on_newfolderbtn_clicked");
     foldertitleentry = lookup_widget(newfolderdialog, "foldertitleentry");
-    foldertitle =
-     (gchar *) gtk_entry_get_text(GTK_ENTRY(foldertitleentry));
-    
-    if(foldertitle == NULL)
+    foldertitle = (gchar *) gtk_entry_get_text(GTK_ENTRY(foldertitleentry));
+
+    if (foldertitle == NULL)
         return;
 
+    /* FIXME: gtk_entry_get_text returns CONST string and asks not to modify it... */
     foldertitle = g_strstrip(foldertitle);
-    
+
     folder_tmp = g_object_get_data(G_OBJECT(newfolderdialog),
-                       "parent_folder");
+                                   "parent_folder");
     parent = (folder_tmp != NULL)
-            ? folder_tmp : ui_feedlist_get_root_folder();    
+        ? folder_tmp : ui_feedlist_get_root_folder();
 
     GtkTreeIter *parent_iter = &((ui_data *) (parent->ui_data))->row;
-    if(ui_folder_check_if_exists(parent_iter, foldertitle))
-    //if(ui_folder_check_if_exists(NULL, foldertitle))
+    if (ui_folder_check_if_exists(parent_iter, foldertitle))
     {
-        gtk_infoprint(GTK_WINDOW(app_data->app_ui_data->app), 
-	    dgettext(HILDON_COMMON_STRINGS_L10N_PACKAGE, "ckdg_ib_folder_already_exists"));
-    return;
+        hildon_banner_show_information(GTK_WIDGET
+                                       (app_data->app_ui_data->main_view),
+                                       NULL,
+                                       dgettext
+                                       (HILDON_COMMON_STRINGS_L10N_PACKAGE,
+                                        "ckdg_ib_folder_already_exists"));
+        return;
     }
-                           
-    if (strcmp(foldertitle, "")) 
-    {
-        folder = restore_folder(NULL, foldertitle, NULL, FST_FOLDER);
-        
-    if (folder) 
-    {
-        /* add the new folder to the model */
-        ui_feedlist_add(parent, (nodePtr) folder, -1);
-        ui_feedlist_select((nodePtr) folder);
-        ui_feedlist_update();
-        treeview = g_object_get_data(G_OBJECT(newfolderdialog),
-                     "folder_treeview");
-        treemodel = g_object_get_data(G_OBJECT(newfolderdialog),
-                      "folder_treemodel");
-     
-        if (treeview != NULL && treemodel != NULL) 
-        {
-             /* All folders are shown in the 
-               manage folders dialog. */
-            //gtk_tree_view_expand_all(GTK_TREE_VIEW(treeview));
 
-            search_result =
-            ui_feedlist_search_model_by_ptr
-            (GTK_TREE_MODEL(treemodel), (nodePtr) folder, &path, NULL);
-        
-            if (search_result && path != NULL) 
-            {
-                gtk_tree_view_expand_to_path(treeview, path);
-                gtk_tree_view_set_cursor
-                    (GTK_TREE_VIEW(treeview), path, NULL, FALSE);
-            } 
-            else 
-            {
-                g_warning("could not find the new folder " "in the model");
+    if (strcmp(foldertitle, "")) {
+        folder = restore_folder(NULL, foldertitle, NULL, FST_FOLDER);
+
+        if (folder) {
+            /* add the new folder to the model */
+            ui_feedlist_add(parent, (nodePtr) folder, -1);
+            ui_feedlist_select((nodePtr) folder);
+            ui_feedlist_update();
+            treeview = g_object_get_data(G_OBJECT(newfolderdialog),
+                                         "folder_treeview");
+            treemodel = g_object_get_data(G_OBJECT(newfolderdialog),
+                                          "folder_treemodel");
+
+            if (treeview != NULL && treemodel != NULL) {
+                search_result =
+                    ui_feedlist_search_model_by_ptr
+                    (GTK_TREE_MODEL(treemodel), (nodePtr) folder, &path,
+                     NULL);
+
+                if (search_result && path != NULL) {
+                    gtk_tree_view_expand_to_path(treeview, path);
+                    gtk_tree_view_set_cursor
+                        (GTK_TREE_VIEW(treeview), path, NULL, FALSE);
+                } else {
+                    g_warning("could not find the new folder "
+                              "in the model");
+                }
+                gtk_tree_path_free(path);
+                path = NULL;
             }
-            gtk_tree_path_free(path);
-            path = NULL;
-        } 
-        gtk_widget_destroy(newfolderdialog);
-         } 
-         else 
-         {
-           g_warning("internal error! could not get a new folder key!");
-         }
-    } 
-    else 
-    {
-       gtk_infoprint(GTK_WINDOW(app_data->app_ui_data->app), 
-	    dgettext(HILDON_COMMON_STRINGS_L10N_PACKAGE, "ckdg_ib_enter_name"));
-        gtk_entry_set_text(foldertitleentry,
-            dgettext(HILDON_FM_L10N_PACKAGE, "ckdg_va_new_folder_name_stub"));
+            gtk_widget_destroy(newfolderdialog);
+        } else {
+            g_warning("internal error! could not get a new folder key!");
+        }
+    } else {
+        hildon_banner_show_information(GTK_WIDGET
+                                       (app_data->app_ui_data->main_view),
+                                       NULL,
+                                       dgettext
+                                       (HILDON_COMMON_STRINGS_L10N_PACKAGE,
+                                        "ckdg_ib_enter_name"));
+        gtk_entry_set_text(GTK_ENTRY(foldertitleentry),
+                           dgettext(HILDON_FM_L10N_PACKAGE,
+                                    "ckdg_va_new_folder_name_stub"));
         gtk_editable_select_region(GTK_EDITABLE(foldertitleentry), 0, 1000);
     }
 }
 
+void ui_folder_close_rename_dialog(void)
+{
+    if (NULL == foldernamedialog || !G_IS_OBJECT(foldernamedialog))
+        return;
+    if (GTK_WIDGET_VISIBLE(foldernamedialog)) {
+        gtk_widget_hide(foldernamedialog);
+    }
+}
+
 void create_folder_rename_dialog(folderPtr folder)
 {
     GtkWidget *foldernameentry;
     gchar *title = NULL;
 
     if ((NULL == folder) || (FST_FOLDER != folder->type)) {
-    return;
+        return;
     }
 
     if (NULL == foldernamedialog || !G_IS_OBJECT(foldernamedialog))
-    foldernamedialog = create_foldernamedialog();
+        foldernamedialog = create_foldernamedialog();
 
     foldernameentry = lookup_widget(foldernamedialog, "foldernameentry");
     title = folder_get_title(folder);
     gtk_entry_set_text(GTK_ENTRY(foldernameentry), title);
     gtk_object_set_data(GTK_OBJECT(foldernamedialog), "folder", folder);
 
-    gtk_widget_show(foldernamedialog);
+    gtk_widget_show_all(foldernamedialog);
 }
 
 void on_foldernamechangebtn_clicked(GtkButton * button, gpointer user_data)
@@ -331,57 +358,56 @@ void on_foldernamechangebtn_clicked(GtkButton * button, gpointer user_data)
     folderPtr folder = NULL;
     GtkWidget *foldernameentry;
     GtkTreeIter parent_iter;
-    
+
     folder = gtk_object_get_data(GTK_OBJECT(foldernamedialog), "folder");
     foldernameentry = lookup_widget(foldernamedialog, "foldernameentry");
-    title = (gchar *)gtk_entry_get_text(GTK_ENTRY(foldernameentry));
-    
-    if(!strcmp(title, ""))
-    {
-        gtk_infoprint(GTK_WINDOW(app_data->app_ui_data->app), 
-	    dgettext(HILDON_COMMON_STRINGS_L10N_PACKAGE, "ckdg_ib_enter_name"));
+    title = (gchar *) gtk_entry_get_text(GTK_ENTRY(foldernameentry));
+
+    if (!strcmp(title, "")) {
+        hildon_banner_show_information(GTK_WIDGET
+                                       (app_data->app_ui_data->main_view),
+                                       NULL,
+                                       dgettext
+                                       (HILDON_COMMON_STRINGS_L10N_PACKAGE,
+                                        "ckdg_ib_enter_name"));
         return;
     }
-    if (strcmp (title, folder->title) == 0)
-    {
-        ULOG_DEBUG("on_foldernamechangebtn_clicked: folder name is the same, returning....");
+    if (strcmp(title, folder->title) == 0) {
         /*TODO: just hide ? */
         gtk_widget_hide(foldernamedialog);
-
         return;
     }
-    ULOG_DEBUG("on_foldernamechangbtnclicked: tvh");
     /* get the parent iter of this folder */
     GtkTreeIter *iter = &((ui_data *) (folder->ui_data))->row;
-    GtkTreePath *path = gtk_tree_model_get_path  (GTK_TREE_MODEL(feedstore),iter);
-    if (TRUE == gtk_tree_path_up(path))
-    {
-        ULOG_DEBUG("on_foldernamechangbtnclicked:  path up");
-        gtk_tree_model_get_iter  (GTK_TREE_MODEL(feedstore), 
-                                            &parent_iter, path);
-        gtk_tree_path_free(path);
-        ULOG_DEBUG("on_foldernamechangbtnclicked: got parent iter");
-     }       
-    if(!ui_folder_check_if_exists(&parent_iter, title))
-    //if(!ui_folder_check_if_exists(NULL, title))
+    GtkTreePath *path =
+        gtk_tree_model_get_path(GTK_TREE_MODEL(feedstore), iter);
+    if (TRUE == gtk_tree_path_up(path)) {
+        gtk_tree_model_get_iter(GTK_TREE_MODEL(feedstore),
+                                &parent_iter, path);
+    }
+    gtk_tree_path_free(path);
+    if (!ui_folder_check_if_exists(&parent_iter, title))
     {
         folder_set_title(folder, title);
         ui_feedlist_update();
         gtk_widget_hide(foldernamedialog);
-    }
-    else
-        gtk_infoprint(GTK_WINDOW(app_data->app_ui_data->app), 
-	    dgettext(HILDON_COMMON_STRINGS_L10N_PACKAGE, "ckdg_ib_folder_already_exists"));
+    } else
+        hildon_banner_show_information(GTK_WIDGET
+                                       (app_data->app_ui_data->main_view),
+                                       NULL,
+                                       dgettext
+                                       (HILDON_COMMON_STRINGS_L10N_PACKAGE,
+                                        "ckdg_ib_folder_already_exists"));
 }
 
 void ui_folder_remove(gpointer callback_data, guint callback_action,
-              GtkWidget * widget)
+                      GtkWidget * widget)
 {
     folderPtr folder = (folderPtr) callback_data;
 
     g_assert((NULL != folder) && (FST_FOLDER == folder->type));
     if (folder == ui_feedlist_get_root_folder()) {
-    ui_feedlist_reset_root_folder();
+        ui_feedlist_reset_root_folder();
     }
     folder_free(folder);
 }
@@ -399,26 +425,24 @@ gboolean ui_is_folder_expanded(folderPtr folder)
     gboolean expanded = FALSE;
 
     g_assert(NULL != feedstore);
-    
+
     g_assert(folder != NULL);
-    
+
     if (folder->ui_data == NULL)
-    return FALSE;
+        return FALSE;
 
     /* Root folder caused warnings with this function
-       so we return. */
+     * so we return. */
     if (folder == ui_feedlist_get_root_folder()) {
-    return TRUE;
+        return TRUE;
     }
 
     if (NULL != (treeview = feedlist)) {
-    iter = &((ui_data *) (folder->ui_data))->row;
-    ui_feedlist_convert_store_iter_to_visible_iter
-        (&visible_iter, iter);
-    path = gtk_tree_model_get_path(feedmodel, &visible_iter);
-    expanded = gtk_tree_view_row_expanded(GTK_TREE_VIEW(treeview),
-                          path);
-    gtk_tree_path_free(path);
+        iter = &((ui_data *) (folder->ui_data))->row;
+        ui_feedlist_convert_store_iter_to_visible_iter(&visible_iter, iter);
+        path = gtk_tree_model_get_path(feedmodel, &visible_iter);
+        expanded = gtk_tree_view_row_expanded(GTK_TREE_VIEW(treeview), path);
+        gtk_tree_path_free(path);
     }
     return expanded;
 }
@@ -429,35 +453,28 @@ void ui_folder_set_expansion(folderPtr folder, gboolean expanded)
     GtkTreePath *path = NULL;
     GtkWidget *treeview = NULL;
     GtkTreeIter visible_iter;
-    //gboolean expansion_changed;
     g_assert(NULL != feedstore);
 
     g_assert(folder != NULL);
-    
-    //expansion_changed = (folder->expanded != expanded);
+
     folder->expanded = expanded;
     if (folder->ui_data == NULL) {
-    return;
+        return;
     }
 
     /* Root folder caused warnings with this function
-       so we return. */
+     * so we return. */
     if (folder == ui_feedlist_get_root_folder()) {
-    return;
+        return;
     }
     if (NULL != (treeview = feedlist)) {
         iter = &((ui_data *) ((nodePtr) folder)->ui_data)->row;
-        ui_feedlist_convert_store_iter_to_visible_iter
-                (&visible_iter, iter);
+        ui_feedlist_convert_store_iter_to_visible_iter(&visible_iter, iter);
         path = gtk_tree_model_get_path(feedmodel, &visible_iter);
-    
 
-        if (expanded)
-        {
+        if (expanded) {
             gtk_tree_view_expand_row(GTK_TREE_VIEW(treeview), path, FALSE);
-        }
-        else
-        {
+        } else {
             gtk_tree_view_collapse_row(GTK_TREE_VIEW(treeview), path);
         }
         gtk_tree_path_free(path);
@@ -467,8 +484,8 @@ void ui_folder_set_expansion(folderPtr folder, gboolean expanded)
 /* Subfolders */
 
 /* this function is a workaround to the cant-drop-rows-into-emtpy-
-   folders-problem, so we simply pack an (empty) entry into each
-   empty folder like Nautilus does... */
+ * folders-problem, so we simply pack an (empty) entry into each
+ * empty folder like Nautilus does... */
 
 void ui_folder_empty_check(folderPtr folder)
 {
@@ -478,50 +495,49 @@ void ui_folder_empty_check(folderPtr folder)
     gboolean valid = FALSE;
     nodePtr ptr = NULL;
     /* this function does two things:
-
-       1. add "(empty)" entry to an empty folder
-       2. remove an "(empty)" entry from a non empty folder
-       (this state is possible after a drag&drop action) */
+     * 
+     * 1. add "(empty)" entry to an empty folder
+     * 2. remove an "(empty)" entry from a non empty folder
+     * (this state is possible after a drag&drop action) */
 
     /* key is folder keyprefix, value is folder tree iterator */
-    count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(feedstore),
-                       parent);
+    count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(feedstore), parent);
 
     /* case 1 */
     if (0 == count) {
         gchar *empty_folder_label = NULL;
-    
-        if(folder == ui_feedlist_get_root_folder())
+
+        if (folder == ui_feedlist_get_root_folder())
             empty_folder_label = g_strdup(_("rss_ia_no_subscribed_feeds"));
-    else
+        else
             empty_folder_label = g_strdup(_("rss_ia_no_feeds"));
-        
-    gtk_tree_store_append(feedstore, &iter, parent);
-    gtk_tree_store_set(feedstore, &iter,
-               FS_LABEL, empty_folder_label,
-               FS_ICON, icons[ICON_RSS_NEWS_FEED],
-               FS_PTR, NULL, FS_UNREAD, 0, -1);
-        
+
+        gtk_tree_store_append(feedstore, &iter, parent);
+        gtk_tree_store_set(feedstore, &iter,
+                           FS_LABEL, empty_folder_label,
+                           FS_ICON, icons[ICON_RSS_NEWS_FEED],
+                           FS_PTR, NULL, FS_UNREAD, 0, -1);
+
         g_free(empty_folder_label);
-                                  
-    return;
+
+        return;
     }
 
     if (1 == count)
-    return;
+        return;
 
     /* else we could have case 2 */
     gtk_tree_model_iter_children(GTK_TREE_MODEL(feedstore), &iter, parent);
     do {
-    gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &iter, FS_PTR, &ptr,
-               -1);
+        gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &iter, FS_PTR, &ptr,
+                           -1);
 
-    if (ptr == NULL) {
-        gtk_tree_store_remove(feedstore, &iter);
-        return;
-    }
+        if (ptr == NULL) {
+            gtk_tree_store_remove(feedstore, &iter);
+            return;
+        }
 
-    valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(feedstore), &iter);
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(feedstore), &iter);
     } while (valid);
 }
 
@@ -532,42 +548,40 @@ void ui_folder_handle_empty_root()
     folderPtr folder = NULL;
     GtkTreeIter *parent = NULL;
     GtkTreeIter iter;
- 
+
     g_assert(feedstore != NULL);
-       
+
     model = GTK_TREE_MODEL(feedstore);
-    
+
     folder = ui_feedlist_get_root_folder();
-    
-    if(folder == NULL)
+
+    if (folder == NULL)
         return;
-    
+
     parent = &((ui_data *) (folder->ui_data))->row;
-    
+
     count = gtk_tree_model_iter_n_children(model, parent);
 
-    if(count == 0)
-    {
+    if (count == 0) {
         gchar *empty_folder_label = NULL;
-    
+
         empty_folder_label = g_strdup(_("rss_ia_no_subscribed_feeds"));
-            
-    gtk_tree_store_append(feedstore, &iter, parent);
-    gtk_tree_store_set(feedstore, &iter,
-               FS_LABEL, empty_folder_label,
-               FS_ICON, icons[ICON_RSS_NEWS_FEED],
-               FS_PTR, NULL, FS_UNREAD, 0, -1);
-        
+
+        gtk_tree_store_append(feedstore, &iter, parent);
+        gtk_tree_store_set(feedstore, &iter,
+                           FS_LABEL, empty_folder_label,
+                           FS_ICON, icons[ICON_RSS_NEWS_FEED],
+                           FS_PTR, NULL, FS_UNREAD, 0, -1);
+
         g_free(empty_folder_label);
-    }                       
+    }
 }
 
 void ui_folder_check_if_empty(void)
 {
-    ULOG_DEBUG("ui_folder_check_if_empty");
     ui_feedlist_do_for_all(NULL,
-               ACTION_FILTER_FOLDER | ACTION_FILTER_ROOT,
-               ui_folder_empty_check);
+                           ACTION_FILTER_FOLDER | ACTION_FILTER_ROOT,
+                           ui_folder_empty_check);
 }
 
 void ui_folder_remove_node(nodePtr ptr)
@@ -577,16 +591,17 @@ void ui_folder_remove_node(nodePtr ptr)
     folderPtr parent = NULL;
 
     g_assert(NULL != ptr);
-    
-    if(ptr->ui_data == NULL)
+
+    if (ptr->ui_data == NULL)
         return;
 
     iter = ((ui_data *) (ptr->ui_data))->row;
     parent = ui_feedlist_get_parent(ptr);
+
     /* If the folder becomes empty, the folder would collapse */
     if (parent != NULL)
-    //parentExpanded = ui_is_folder_expanded(parent);
-    parentExpanded = parent->expanded;
+        parentExpanded = parent->expanded;
+
     gtk_tree_store_remove(feedstore, &iter);
 
     g_free((ui_data *) (ptr->ui_data));
@@ -594,19 +609,17 @@ void ui_folder_remove_node(nodePtr ptr)
 
     if (parent != NULL) {
         ui_folder_check_if_empty();
-        if ((parent != NULL) && parentExpanded)
-        {
+        if ((parent != NULL) && parentExpanded) {
             ui_folder_set_expansion(parent, TRUE);
-            //TODO: There's a bug here about the icon of the parent.
         }
     }
 }
 
-gint  ui_get_marked_from_iter(GtkTreeIter * iter)
+gint ui_get_marked_from_iter(GtkTreeIter * iter)
 {
     gboolean rc = FALSE;
     GtkTreeIter child;
-    gint  marked = 0;
+    gint marked = 0;
     GtkTreeModel *model = NULL;
     folderPtr ptr = NULL;
     nodePtr childptr = NULL;
@@ -615,23 +628,22 @@ gint  ui_get_marked_from_iter(GtkTreeIter * iter)
     g_assert(FST_FOLDER == ptr->type);
     g_assert(ptr != NULL);
     g_assert(ptr->ui_data);
-     rc = gtk_tree_model_iter_children(model, &child, iter);
-     while (rc) {
-     gtk_tree_model_get(model, &child, FS_PTR, &childptr, -1);
-    if (NULL != childptr && FST_FOLDER == childptr->type){
-    marked += ui_get_marked_from_iter(&child);
-    }
-    else if (NULL != childptr && FST_FEED == childptr->type){
-        marked += feed_get_mark_counter((feedPtr) childptr);
-         }
-       rc = gtk_tree_model_iter_next(model, &child);
+    rc = gtk_tree_model_iter_children(model, &child, iter);
+    while (rc) {
+        gtk_tree_model_get(model, &child, FS_PTR, &childptr, -1);
+        if (NULL != childptr && FST_FOLDER == childptr->type) {
+            marked += ui_get_marked_from_iter(&child);
+        } else if (NULL != childptr && FST_FEED == childptr->type) {
+            marked += feed_get_mark_counter((feedPtr) childptr);
+        }
+        rc = gtk_tree_model_iter_next(model, &child);
     }
     return marked;
 }
 
 void ui_folder_collapse_expand_cb(GtkTreeView * widget,
-                  GtkTreeIter * iter,
-                  GtkTreePath * path, gpointer user_data)
+                                  GtkTreeIter * iter,
+                                  GtkTreePath * path, gpointer user_data)
 {
     GtkTreeModel *model;
     GtkTreeIter store_iter;
@@ -643,58 +655,50 @@ void ui_folder_collapse_expand_cb(GtkTreeView * widget,
     if (!lifereaStarted)
         return;
 
-    ULOG_DEBUG(__FUNCTION__);
-
     g_assert(NULL != iter);
 
     model = GTK_TREE_MODEL(feedstore);
     ui_feedlist_convert_visible_iter_to_store_iter(&store_iter, iter);
-    gtk_tree_model_get(model, &store_iter,
-               FS_PTR, &ptr, -1);
+    gtk_tree_model_get(GTK_TREE_MODEL(model), &store_iter, FS_PTR, &ptr, -1);
 
     g_assert(NULL != ptr);
 
-    if(displayed_node != NULL)
-        if(ui_feedlist_is_ancestor((nodePtr)displayed_node, &store_iter))
-    {
-        ui_htmlview_clear(ui_mainwindow_get_active_htmlview());
-        ui_itemlist_clear();
+    if (displayed_node != NULL)
+        if (ui_feedlist_is_ancestor((nodePtr) displayed_node, &store_iter)) {
+            ui_htmlview_clear(ui_mainwindow_get_active_htmlview());
+            ui_itemlist_clear();
             ui_mainwindow_finish();
-        
-        g_assert(app_data != NULL);
-         g_assert(app_data->app_ui_data != NULL);
-    
-        hildon_appview_set_title(app_data->app_ui_data->main_view, "");
+
+            g_assert(app_data != NULL);
+            g_assert(app_data->app_ui_data != NULL);
+
+            gtk_window_set_title(GTK_WINDOW(app_data->app_ui_data->main_view),
+                                 "");
         }
 
-    /*tvh: uses this newly added gboolean in stead of ui_is_folder_expanded */
-        /*Yes... good... but why????? Turning back to old version */
+    ptr->expanded = ui_is_folder_expanded(ptr);
 
-    //ptr->expanded = !ptr->expanded;
-        ptr->expanded = ui_is_folder_expanded(ptr);
-
-    gtk_tree_store_set(model, &store_iter,
-               FS_ICON, ui_folder_select_icon(ptr->expanded), -1);
+    gtk_tree_store_set(GTK_TREE_STORE(model), &store_iter,
+                       FS_ICON, ui_folder_select_icon(ptr->expanded), -1);
 
     //if expanded. We should set all the sub-folders to collapsed
-    if ((ptr->expanded == TRUE) /*&& !ptr->nonremovable*/ )
-    {
-        rc = gtk_tree_model_iter_children(model, &child, &((ui_data *) (ptr->ui_data))->row);
+    if ((ptr->expanded == TRUE)) {
+        rc = gtk_tree_model_iter_children(GTK_TREE_MODEL(model), &child,
+                                          &((ui_data *) (ptr->ui_data))->row);
         while (rc) {
-            gtk_tree_model_get(model, &child, FS_PTR, &childptr, -1);
+            gtk_tree_model_get(GTK_TREE_MODEL(model), &child, FS_PTR,
+                               &childptr, -1);
             if (childptr != NULL)
-            if (FST_FOLDER == childptr->type)
-            {
-                ui_folder_set_expansion( (folderPtr) childptr, FALSE);
-                gtk_tree_store_set(model, &child,
-                       FS_ICON, ui_folder_select_icon(FALSE), -1);
-            }
+                if (FST_FOLDER == childptr->type) {
+                    ui_folder_set_expansion((folderPtr) childptr, FALSE);
+                    gtk_tree_store_set(GTK_TREE_STORE(model), &child,
+                                       FS_ICON, ui_folder_select_icon(FALSE),
+                                       -1);
+                }
 
             rc = gtk_tree_model_iter_next(model, &child);
         }
     }
-
-    /*ULOG_DEBUG("%s END", __FUNCTION__);*/
 }
 
 void ui_folder_update(folderPtr folder)
@@ -705,14 +709,13 @@ void ui_folder_update(folderPtr folder)
         g_assert(FST_FOLDER == node->type);
         g_assert(NULL != node->ui_data);
         ui_folder_update_from_iter(&((ui_data *) (node->ui_data))->row);
-       }
+    }
 }
 
-
-
 void ui_folder_mfdialog_collapse_expand_cb(GtkTreeView * widget,
-                  GtkTreeIter * iter,
-                  GtkTreePath * path, gpointer user_data)
+                                           GtkTreeIter * iter,
+                                           GtkTreePath * path,
+                                           gpointer user_data)
 {
 
     GtkTreeStore *model;
@@ -721,32 +724,31 @@ void ui_folder_mfdialog_collapse_expand_cb(GtkTreeView * widget,
     GtkTreeIter child;
     gboolean rc;
 
-    /* only works with the filtered model of the dialog */    
+    /* only works with the filtered model of the dialog */
     model = (GtkTreeStore *) gtk_tree_view_get_model(widget);
 
-    ULOG_DEBUG("ui_folder_mfdialog_collapse_expand_cb....");
+    gtk_tree_model_get(GTK_TREE_MODEL(model), iter, FS_PTR, &ptr, -1);
 
-    gtk_tree_model_get(model, iter,
-               FS_PTR, &ptr, -1);
-    
     g_assert(NULL != ptr);
     if (FST_FOLDER != ptr->type)
         return;
 
     ptr->dialog_mode_expanded = !ptr->dialog_mode_expanded;
 
-    if ((ptr->dialog_mode_expanded == TRUE) /*&& !ptr->nonremovable*/ )
-    {
-        rc = gtk_tree_model_iter_children(model, &child, iter /*&((ui_data *) (ptr->ui_data))->row*/);
+    if ((ptr->dialog_mode_expanded == TRUE)) {
+        rc = gtk_tree_model_iter_children(GTK_TREE_MODEL(model), &child,
+                                          iter
+                                          );
         while (rc) {
-            gtk_tree_model_get(model, &child, FS_PTR, &childptr, -1);
+            gtk_tree_model_get(GTK_TREE_MODEL(model), &child, FS_PTR,
+                               &childptr, -1);
             if (childptr != NULL)
-            //show always be true in dialog model
-            if (FST_FOLDER == childptr->type)
-            {
-                ((folderPtr) childptr)->dialog_mode_expanded = FALSE;
-            }
-            rc = gtk_tree_model_iter_next(model, &child);
+                //show always be true in dialog model
+                if (FST_FOLDER == childptr->type) {
+                    ((folderPtr) childptr)->dialog_mode_expanded = FALSE;
+                }
+            rc = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &child);
         }
     }
 }
+
